Oracle EBS 12.2 Anypoint&trade; Connector Demo - HR Location CRUD
=================================================================

## Introduction

The present demo application provides a **complete workflow** to sequentially invoke some of Oracle EBS's **standard operations** against the PL/SQL endpoint **HR Location**.

## Prerequisites

* Java 7
* Anypoint Studio 6.x
* Mule Runtime 3.7.x EE or higher
* DataWeave
* Access to a Oracle EBS 12.2 instance

## Import the project

* Go to **File > Import**
* Select **Anypoint Studio Project from External Location** (under the parent folder "Anypoint Studio")
* Provide the root **path to the demo** project folder.
* Select **Mule Runtime (3.8.2 EE)**.
* Click **Finish**.
* Set credentials inside the file `src/main/app/mule-app.properties`.
    ```
    oracle122.username=
    oracle122.password=
    oracle122.host=
    oracle122.port=
    oracle122.responsibility=
    oracle122.restServiceLocatorAlias=
    oracle122.fndWebSecAlias=
    oracle122.respApplication=
    oracle122.securityGroup=
    oracle122.nlsLanguage=
    oracle122.orgId=
    ```

* Open the **Global Element Configuration**.

    ![Global Element](images/oec122-connection-config.png)

* Click the **Test Connection** button to ensure there is connectivity with the sandbox. A successful message should pop-up.

* Open a browser and access the URL **http://localhost:8081/app**. You should see the demo application deployed:

    ![Demo Index](images/oec122-ui.png)


## About the flows

* **Create_HR_Location_Flow:** given a Code and a Description, it creates a new Location record.

* **Get_HR_Location_Flow:** given an ID, it retrieves the information of a Location.

* **Update_HR_Location_Flow:** given the ID and the Version Number of an existing Location, it updates the Code and/or Description.

+ **Delete_HR_Location_Flow:** removes a Location given its ID and Version Number.


### Additional flows

* **Service_Load_Flow:** loads all static resources related to the UI.

* **Styles_Flow:** loads the CSS stylesheet file.

* **Global_Exception_Strategy:** handles the exceptions thrown by the connector and forwards the error message to the HTML page.


## Run the demo

### Create Location

![Create Location](images/oec122-ui-create.png)

* Provide a **Code** (must be unique) and a **Description** for the new location.
* Click the button **Create** and wait a few moments to finish processing.
* If successfully created, a message will pop-up informing the ID of the location record.

### Get Location

![Get Location(s)](images/oec122-ui-get.png)

* Provide the ID of an existent location.
* Click the button **Get** and wait a few moments to finish processing.
* The complete details of the location will be displayed inside a textarea.

### Update Location

![Update Location](images/oec122-ui-update.png)

* Provide the **ID** of an existing location, the **Version** number, a **Code** and a **Description**.
* Click the **Update** button  and wait a few moments to finish processing.
* To confirm the location fields where modified, go back to the previous tab and execute the **Get** operation.
* If successfully updated, a message containing the new current version of the location will be displayed.

### Delete Location

![Delete Location](images/oec122-ui-delete.png)

* Provide the **ID** of an existing location and the the **Version** number.
* Click the button **Delete** and wait a few moments to finish processing.
* If successfully deleted, a message will pop-up stating so.

## See more

* For additional technical information on the Oracle EBS 12.2 Connector, visit our [technical reference documentation](http://mulesoft.github.io/oracle-ebs-122-connector) or refer to the [Oracle EBS 12.2 Documentation Site](https://docs.mulesoft.com/mule-user-guide/v/3.8/oracle-ebs-122-connector).
* For more information on the Oracle EBS 12.2, go to the [Oracle EBS 12.2 REST Services blog](https://blogs.oracle.com/stevenChan/entry/introducing_oracle_e_business_suite).